@@ -39,6 +39,7 @@
 #![warn(
     trivial_casts,
     trivial_numeric_casts,
+    unreachable_pub,
     unused,
     unused_extern_crates,
     unused_import_braces,
@@ -67,8 +68,7 @@ pub use config::Config;
 pub use connection_pool::ConnId;
 pub use connections::{DisconnectionEvents, RecvStream, SendStream};
 pub use endpoint::{Endpoint, IncomingConnections, IncomingMessages};
-pub use error::{Error, Result};
-pub use quinn::ConnectionError;
+pub use error::{Close, ConnectionError, Error, Result};
 
 #[cfg(test)]
 mod tests;
